==> 1.0.3.tar.gz: lib/mixins/relive_it_mixin.dart <==
import 'package:facts/ext/ext.dart';
import 'package:facts/facts.dart';
import 'package:facts/model/trait.dart';
import 'package:sunny_sdk_core/model_exports.dart';
import 'package:sunny_service_stubs/models/sunny/sunny.dart';

mixin ReactionApiMixin {}
mixin ReactionListMixin implements MModelList<Reaction> {}
mixin PhaseListMixin implements MModelList<Phase> {}
mixin PhaseMixin {}
mixin PhaseApiMixin {}
mixin ReactionMixin implements IReaction {
  MKey? get contactKey => this.user;
  set contactKey(MKey? contactKey) => user = contactKey;

  String? title(IContact contact) {
    return this.comment;
  }

  String? subtitle(IContact contact) {
    return null;
  }
}

mixin PossessionMixin implements IPossession, SmartNotesItem {
  MKey? contactKey;

  String? title(IContact contact) {
    return this.itemName;
  }

  String? subtitle(IContact contact) {
    return details;
  }
}
mixin PossessionApiMixin {}
mixin PossessionListMixin implements MModelList<Possession> {}

mixin TraitMixin implements ITrait, SmartNotesItem {
  MKey? contactKey;

  String? title(IContact contact) {
    return this.traitTitle;
  }

  String? subtitle(IContact contact) {
    return this.traitDescription;
  }
}
mixin TraitApiMixin {}
mixin TraitListMixin implements MModelList<Trait> {}

mixin TraditionMixin implements ITradition, SmartNotesItem {
  MKey? contactKey;

  String? title(IContact contact) {
    return this.traditionTitle;
  }

  String? subtitle(IContact contact) {
    return this.description;
  }
}
mixin TraditionApiMixin {}
mixin TraditionListMixin implements MModelList<Tradition> {}

==> 1.0.5.tar.gz: lib/mixins/relive_it_mixin.dart <==
import 'package:facts/ext/ext.dart';
import 'package:facts/facts.dart';
import 'package:facts/model/trait.dart';
import 'package:sunny_sdk_core/model_exports.dart';
import 'package:sunny_service_stubs/contact.dart';

mixin ReactionApiMixin {}
mixin ReactionListMixin implements MModelList<Reaction> {}
mixin PhaseListMixin implements MModelList<Phase> {}
mixin PhaseMixin {}
mixin PhaseApiMixin {}
mixin ReactionMixin implements IReaction {
  MKey? get contactKey => this.user;
  set contactKey(MKey? contactKey) => user = contactKey;

  String? title(IRef contact) {
    return this.comment;
  }

  String? subtitle(IRef contact) {
    return null;
  }
}

mixin PossessionMixin implements IPossession, SmartNotesItem {
  MKey? contactKey;

  String? title(IRef contact) {
    return this.itemName;
  }

  String? subtitle(IRef contact) {
    return details;
  }
}
mixin PossessionApiMixin {}
mixin PossessionListMixin implements MModelList<Possession> {}

mixin TraitMixin implements ITrait, SmartNotesItem {
  MKey? contactKey;

  String? title(IRef contact) {
    return this.traitTitle;
  }

  String? subtitle(IRef contact) {
    return this.traitDescription;
  }
}
mixin TraitApiMixin {}
mixin TraitListMixin implements MModelList<Trait> {}

mixin TraditionMixin implements ITradition, SmartNotesItem {
  MKey? contactKey;

  String? title(IRef contact) {
    return this.traditionTitle;
  }

  String? subtitle(IRef contact) {
    return this.description;
  }
}
mixin TraditionApiMixin {}
mixin TraditionListMixin implements MModelList<Tradition> {}
